"""The 'windows' module provides the window classes for the main
application window as well as dialogs."""
#  MIT Licence
#  Copyright (c) 2024 Asger Jon Vistisen
from __future__ import annotations

from ._base_window import BaseWindow
from ._layout_window import LayoutWindow
